==> crow-2.11.0.tar.bz2: crow-2.11.0/crow/views3.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005 Maxim Udushlivy
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef CROW_VIEWS3_H
#define CROW_VIEWS3_H

#include "views2.h"

namespace Crow {

class GtkEntryCompletionView : public GlibObjectView {

public:
	GtkEntryCompletionView();

protected:
	Any createInstance();

};

class GtkEntryView : public GtkWidgetView, public TCreateInstance<Gtk::Entry> {

public:
	using TCreateInstance<Gtk::Entry>::getObject;

	GtkEntryView();

protected:
	void initDesign();
	Any getCompletion(Property * property);
	void setCompletion(Property * property, Any value);
	void setInnerBorderSet(Property * property, Any value);
	void setInnerBorder(Property * property, Any value);

};

class GtkComboBoxView : public GtkContainerViewBase {

public:
	GtkComboBoxView();

protected:
	using GlibObjectView::getObject;

	Any createInstance();
	void setTextMode(Property * property, Any value);
	virtual void setStrings(Property * property, Any value);
	virtual void clearStrings();

};

class GtkComboBoxEntryView : public GtkComboBoxView {

public:
	GtkComboBoxEntryView();

protected:
	Any createInstance();
	Any getEntry(Property * property);
	Any getText(Property * property);
	void setText(Property * property, Any value);
	void setActive(Property * property, Any value);
	void configureEntry(Property * property, PEntityView ev);
	void setStrings(Property * property, Any value);
	void clearStrings();
	void activeChanged(int old);

};

class GtkSpinButtonView : public GtkEntryView {

public:
	GtkSpinButtonView();

protected:
	Any createInstance();
	void initDesign();
	void configureAdjustment(Property * property, PEntityView view);

};

class GtkRangeView : public GtkWidgetView {

public:
	GtkRangeView();

};

class GtkScaleView : public GtkRangeView {

public:
	GtkScaleView();

};

class GtkHScaleView : public GtkScaleView, public TCreateInstance<Gtk::HScale> {
};

class GtkVScaleView : public GtkScaleView, public TCreateInstance<Gtk::VScale> {
};

class GtkProgressBarView : public GtkWidgetView, public TCreateInstance<Gtk::ProgressBar> {

public:
	GtkProgressBarView();

};

class GtkImageView : public GtkMiscView, public TCreateInstance<Gtk::Image> {

public:
	using TCreateInstance<Gtk::Image>::getObject;

	GtkImageView();

protected:
	void initInstance();

};

class GtkHSeparatorView : public GtkWidgetView, public TCreateInstance<Gtk::HSeparator> {
};

class GtkVSeparatorView : public GtkWidgetView, public TCreateInstance<Gtk::VSeparator> {
};

class GtkSizeGroupView : public GlibObjectView {

public:
	GtkSizeGroupView();

protected:
	Any createInstance();
	void doneInstance();
	void clearWidgets();
	void setWidgets(Property * property, Any value);

};

class GtkTextViewView : public GtkContainerViewBase, public TCreateInstance<Gtk::TextView> {

public:
	using TCreateInstance<Gtk::TextView>::getObject;

	GtkTextViewView();

protected:
	void initDesign();
	Any getText(Property * property);
	void setText(Property * property, Any value);

};

class GtkIconViewView : public GtkContainerViewBase, public TCreateInstance<Gtk::IconView> {

public:
	using TCreateInstance<Gtk::IconView>::getObject;

	GtkIconViewView();

protected:
	void initDesign();
	void setSampleData(Property * property, Any value);

};

class GtkCellViewView : public GtkWidgetView, public TCreateInstance<Gtk::CellView> {

public:
	using TCreateInstance<Gtk::CellView>::getObject;

	GtkCellViewView();

protected:
	void initDesign();
	void setBackgroundSet(Property * property, Any value);
	void setSampleData(Property * property, Any value);

};

class GtkTreeViewView : public GtkContainerViewBase, public TCreateInstance<Gtk::TreeView> {

public:
	using TCreateInstance<Gtk::TreeView>::getObject;

	GtkTreeViewView();

protected:
	void initDesign();
	void doneInstance();
	Any getSelectionMode(Property * property);
	void setSelectionMode(Property * property, Any value);
	void setSampleData(Property * property, Any value);
	void setSearchEntry(Property * property, Any value);

};

class GtkColorButtonView : public GtkContainerViewBase, public GtkButtonViewBase, public TCreateInstance<Gtk::ColorButton> {

public:
	GtkColorButtonView();

};

class GtkColorSelectionView : public GtkContainerViewBase, public TCreateInstance<Gtk::ColorSelection> {

public:
	using TCreateInstance<Gtk::ColorSelection>::getObject;

	GtkColorSelectionView();

protected:
	void setHasOpacityControl(Property * property, Any value);

};

class GtkFileChooserButtonView : public GtkContainerViewBase, public GtkFileChooserViewBase {

public:
	GtkFileChooserButtonView();

protected:
	Any createInstance();
	bool isActiveWidget(Gtk::Widget * widget);

};

class GtkFileChooserWidgetView : public GtkContainerViewBase, public GtkFileChooserViewBase {

protected:
	Any createInstance();

};

class GtkFontButtonView : public GtkContainerViewBase, public GtkButtonViewBase, public TCreateInstance<Gtk::FontButton> {

public:
	GtkFontButtonView();

};

class GtkFontSelectionView : public GtkContainerViewBase, public TCreateInstance<Gtk::FontSelection> {
};

class GtkFixedView : public XYContainerView, public TGtkContainerView<FixedContainer>, public TCreateInstance<Gtk::Fixed> {

public:
	using TGtkContainerView<FixedContainer>::getObject;

	GtkFixedView();

protected:
	void initInstance();
	void setupContainer();
	void setChildren(Property * property, Any value);

};

class GtkLayoutView : public XYContainerView, public TGtkContainerView<LayoutContainer>, public TCreateInstance<Gtk::Layout> {

public:
	using TGtkContainerView<LayoutContainer>::getObject;

	GtkLayoutView();

protected:
	PGdkWindow getExposeWindow();
	void setupContainer();
	void setChildren(Property * property, Any value);
	Any getSize(Property * property);
	void setSize(Property * property, Any value);

};

class GtkScrollbarView : public GtkRangeView {

public:
	GtkScrollbarView();

};

class GtkHScrollbarView : public GtkScrollbarView, public TCreateInstance<Gtk::HScrollbar> {
};

class GtkVScrollbarView : public GtkScrollbarView, public TCreateInstance<Gtk::VScrollbar> {
};

class GtkEventBoxView : public GtkBinView, public TCreateInstance<Gtk::EventBox> {

public:
	GtkEventBoxView();

};

class GtkDrawingAreaView : public GtkWidgetView, public TCreateInstance<Gtk::DrawingArea> {

public:
	GtkDrawingAreaView();

};

class GtkCalendarView : public GtkWidgetView, public TCreateInstance<Gtk::Calendar> {

public:
	GtkCalendarView();

};

class GtkArrowView : public GtkMiscView {

public:
	GtkArrowView();

protected:
	Any createInstance();

};

class CustomView : public GtkWidgetView {

public:
	CustomView();
	Any createInstance();

};

class ButtonView : public GtkButtonView {

protected:
	Any createInstance();

};

class WindowView : public GtkWindowView {

protected:
	Gtk::Widget * createDesignWindow();

};

class GtkStatusIconView : public GlibObjectView {

public:
	GtkStatusIconView();

protected:
	Any createInstance();

};

class GtkLinkButtonView : public GtkContainerViewBase, public GtkButtonViewBase, public TCreateInstance<Gtk::LinkButton> {

public:
	GtkLinkButtonView();

protected:
	void initDesign();
	Any createInstance();

};

class GtkRecentFilterView : public GlibObjectView {

public:
	GtkRecentFilterView();

protected:
	Any createInstance();
	Any getName(Property * property);
	void setName(Property * property, Any value);

};

class GtkRecentChooserViewBase : public virtual GtkWidgetView {

public:
	GtkRecentChooserViewBase();

	virtual Glib::RefPtr<Gtk::RecentChooser> getObject();

protected:
	void initInstance();
	void initGtkRecentChooserInstance();
	void setFilters(Property * property, Any value);
	void setFilter(Property * property, Any value);
	void clearFilters();

};

class GtkRecentChooserWidgetView : public GtkContainerViewBase, public GtkRecentChooserViewBase, public TCreateInstance<Gtk::RecentChooserWidget> {
};

class GtkRecentChooserDialogView : public GtkDialogViewFinal, public GtkRecentChooserViewBase {

public:
	GtkRecentChooserDialogView();

	Glib::RefPtr<Gtk::RecentChooser> getObject();
	
protected:
	void initInstance();
	Gtk::Widget * createDesignWindow();

};

}

#endif

==> crow-2.11.3.tar.bz2: crow-2.11.3/crow/views3.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2008 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef CROW_VIEWS3_H
#define CROW_VIEWS3_H

#include "views2.h"

namespace Crow {

class GtkEntryCompletionView : public GlibObjectView {

public:
	GtkEntryCompletionView();

protected:
	Any createInstance();

};

class GtkEntryView : public GtkWidgetView, public TCreateInstance<Gtk::Entry> {

public:
	using TCreateInstance<Gtk::Entry>::getObject;

	GtkEntryView();

protected:
	void initDesign();
	Any getCompletion(Property * property);
	void setCompletion(Property * property, Any value);
	void setInnerBorderSet(Property * property, Any value);
	void setInnerBorder(Property * property, Any value);
	void setShadowType(Property * property, Any value);

};

class GtkComboBoxView : public GtkContainerViewBase {

public:
	GtkComboBoxView();

protected:
	using GlibObjectView::getObject;

	Any createInstance();
	void setTextMode(Property * property, Any value);
	virtual void setStrings(Property * property, Any value);
	virtual void clearStrings();

};

class GtkComboBoxEntryView : public GtkComboBoxView {

public:
	GtkComboBoxEntryView();

protected:
	Any createInstance();
	Any getEntry(Property * property);
	Any getText(Property * property);
	void setText(Property * property, Any value);
	void setActive(Property * property, Any value);
	void configureEntry(Property * property, PEntityView ev);
	void setStrings(Property * property, Any value);
	void clearStrings();
	void activeChanged(int old);

};

class GtkSpinButtonView : public GtkEntryView {

public:
	GtkSpinButtonView();

protected:
	Any createInstance();
	void initDesign() { }
	void configureAdjustment(Property * property, PEntityView view);

};

class GtkRangeView : public GtkWidgetView {

public:
	GtkRangeView();

protected:
	void initInstance();
	
};

class GtkScaleView : public GtkRangeView {

public:
	GtkScaleView();

};

class GtkHScaleView : public GtkScaleView, public TCreateInstance<Gtk::HScale> {
};

class GtkVScaleView : public GtkScaleView, public TCreateInstance<Gtk::VScale> {
};

class GtkProgressBarView : public GtkWidgetView, public TCreateInstance<Gtk::ProgressBar> {

public:
	GtkProgressBarView();

};

class GtkImageView : public GtkMiscView, public TCreateInstance<Gtk::Image> {

public:
	using TCreateInstance<Gtk::Image>::getObject;

	GtkImageView();

protected:
	void initInstance();

};

class GtkHSeparatorView : public GtkWidgetView, public TCreateInstance<Gtk::HSeparator> {
};

class GtkVSeparatorView : public GtkWidgetView, public TCreateInstance<Gtk::VSeparator> {
};

class GtkSizeGroupView : public GlibObjectView {

public:
	GtkSizeGroupView();

protected:
	Any createInstance();
	void doneInstance();
	void clearWidgets();
	void setWidgets(Property * property, Any value);

};

class GtkTextViewView : public GtkContainerViewBase, public TCreateInstance<Gtk::TextView> {

public:
	using TCreateInstance<Gtk::TextView>::getObject;

	GtkTextViewView();

protected:
	void initDesign();
	Any getText(Property * property);
	void setText(Property * property, Any value);

};

class GtkIconViewView : public GtkContainerViewBase, public TCreateInstance<Gtk::IconView> {

public:
	using TCreateInstance<Gtk::IconView>::getObject;

	GtkIconViewView();

protected:
	void initDesign();
	void setSampleData(Property * property, Any value);

};

class GtkCellViewView : public GtkWidgetView, public TCreateInstance<Gtk::CellView> {

public:
	using TCreateInstance<Gtk::CellView>::getObject;

	GtkCellViewView();

protected:
	void initDesign();
	void setBackgroundSet(Property * property, Any value);
	void setSampleData(Property * property, Any value);

};

class GtkTreeViewView : public GtkContainerViewBase, public TCreateInstance<Gtk::TreeView> {

public:
	using TCreateInstance<Gtk::TreeView>::getObject;

	GtkTreeViewView();

protected:
	void initDesign();
	void doneInstance();
	Any getSelectionMode(Property * property);
	void setSelectionMode(Property * property, Any value);
	void setSampleData(Property * property, Any value);
	void setSearchEntry(Property * property, Any value);

};

class GtkColorButtonView : public GtkContainerViewBase, public GtkButtonViewBase, public TCreateInstance<Gtk::ColorButton> {

public:
	GtkColorButtonView();

};

class GtkColorSelectionView : public GtkContainerViewBase, public TCreateInstance<Gtk::ColorSelection> {

public:
	using TCreateInstance<Gtk::ColorSelection>::getObject;

	GtkColorSelectionView();

protected:
	void setHasOpacityControl(Property * property, Any value);

};

class GtkFileChooserButtonView : public GtkContainerViewBase, public GtkFileChooserViewBase {

public:
	GtkFileChooserButtonView();

protected:
	Any createInstance();
	bool isActiveWidget(Gtk::Widget * widget);

};

class GtkFileChooserWidgetView : public GtkContainerViewBase, public GtkFileChooserViewBase {

protected:
	Any createInstance();

};

class GtkFontButtonView : public GtkContainerViewBase, public GtkButtonViewBase, public TCreateInstance<Gtk::FontButton> {

public:
	GtkFontButtonView();

};

class GtkFontSelectionView : public GtkContainerViewBase, public TCreateInstance<Gtk::FontSelection> {
};

class GtkFixedView : public XYContainerView, public TGtkContainerView<FixedContainer>, public TCreateInstance<Gtk::Fixed> {

public:
	using TGtkContainerView<FixedContainer>::getObject;

	GtkFixedView();

protected:
	void initInstance();
	void setupContainer();
	void setChildren(Property * property, Any value);

};

class GtkLayoutView : public XYContainerView, public TGtkContainerView<LayoutContainer>, public TCreateInstance<Gtk::Layout> {

public:
	using TGtkContainerView<LayoutContainer>::getObject;

	GtkLayoutView();

protected:
	PGdkWindow getExposeWindow();
	void setupContainer();
	void setChildren(Property * property, Any value);
	Any getSize(Property * property);
	void setSize(Property * property, Any value);

};

class GtkScrollbarView : public GtkRangeView {

public:
	GtkScrollbarView();

};

class GtkHScrollbarView : public GtkScrollbarView, public TCreateInstance<Gtk::HScrollbar> {
};

class GtkVScrollbarView : public GtkScrollbarView, public TCreateInstance<Gtk::VScrollbar> {
};

class GtkEventBoxView : public GtkBinView, public TCreateInstance<Gtk::EventBox> {

public:
	GtkEventBoxView();

};

class GtkDrawingAreaView : public GtkWidgetView, public TCreateInstance<Gtk::DrawingArea> {

public:
	GtkDrawingAreaView();

};

class GtkCalendarView : public GtkWidgetView, public TCreateInstance<Gtk::Calendar> {

public:
	GtkCalendarView();

};

class GtkArrowView : public GtkMiscView {

public:
	GtkArrowView();

protected:
	Any createInstance();

};

class CustomView : public GtkWidgetView {

public:
	CustomView();
	Any createInstance();

};

class ButtonView : public GtkButtonView {

protected:
	Any createInstance();

};

class WindowView : public GtkWindowView {

protected:
	Gtk::Widget * createDesignWindow();

};

class GtkStatusIconView : public GlibObjectView {

public:
	GtkStatusIconView();

protected:
	Any createInstance();

};

class GtkLinkButtonView : public GtkContainerViewBase, public GtkButtonViewBase, public TCreateInstance<Gtk::LinkButton> {

public:
	GtkLinkButtonView();

protected:
	void initDesign();
	Any createInstance();

};

class GtkRecentFilterView : public GlibObjectView {

public:
	GtkRecentFilterView();

protected:
	Any createInstance();
	Any getName(Property * property);
	void setName(Property * property, Any value);

};

class GtkRecentChooserViewBase : public virtual GlibObjectView {

public:
	GtkRecentChooserViewBase();

	virtual Glib::RefPtr<Gtk::RecentChooser> getObject();

protected:
	void initInstance();
	void initRecentChooserInstance();
	void setFilters(Property * property, Any value);
	void setFilter(Property * property, Any value);
	void clearFilters();

};

class GtkRecentChooserWidgetView : public GtkContainerViewBase, public GtkRecentChooserViewBase, public TCreateInstance<Gtk::RecentChooserWidget> {

protected:
	void initInstance();

};

class GtkRecentChooserDialogView : public GtkDialogViewFinal, public GtkRecentChooserViewBase {

public:
	GtkRecentChooserDialogView();

	Glib::RefPtr<Gtk::RecentChooser> getObject();
	
protected:
	void initInstance();
	Gtk::Widget * createDesignWindow();

};

class GtkRecentActionView : public GtkActionView, public GtkRecentChooserViewBase {

public:
	GtkRecentActionView();

protected:
	Any createInstance();

};

}

#endif
